@@ -63,6 +63,10 @@ func checkDiffConfig(cfg *config.Config) error {
 		if projectConfig.TerraformUseState {
 			return errors.New("terraform_use_state cannot be used with `infracost diff` as the Terraform state only contains the current state")
 		}
+
+		if projectConfig.TerraformParseHCL && cfg.CompareTo == "" {
+			return errors.New("Use `infracost diff --path /code --terraform-parse-hcl --compare-to infracost-previous-run.json` to generate a diff")
+		}
 	}
 
 	return nil
