@@ -55,8 +55,15 @@ func NewDashboardAPIClient(ctx *config.RunContext) *DashboardAPIClient {
 	}
 }
 
-func (c *DashboardAPIClient) CreateAPIKey(name string, email string, ciInterest bool) (CreateAPIKeyResponse, error) {
-	d := map[string]interface{}{"name": name, "email": email, "ci": ciInterest}
+func (c *DashboardAPIClient) CreateAPIKey(name string, email string, ciInterest bool, contextVals map[string]interface{}) (CreateAPIKeyResponse, error) {
+	d := map[string]interface{}{
+		"name":        name,
+		"email":       email,
+		"ci":          ciInterest,
+		"os":          contextVals["os"],
+		"version":     contextVals["version"],
+		"fullVersion": contextVals["fullVersion"],
+	}
 	respBody, err := c.doRequest("POST", "/apiKeys?source=cli-register", d)
 	if err != nil {
 		return CreateAPIKeyResponse{}, err
