@@ -6,7 +6,6 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
-	"strings"
 	"sync"
 
 	"github.com/awslabs/goformation/v4"
@@ -43,7 +42,7 @@ func (e *ValidationError) Error() string {
 	return e.err
 }
 
-func Detect(ctx *config.ProjectContext) (schema.Provider, error) {
+func Detect(ctx *config.ProjectContext, includePastResources bool) (schema.Provider, error) {
 	path := ctx.ProjectConfig.Path
 
 	if _, err := os.Stat(path); os.IsNotExist(err) {
@@ -51,9 +50,13 @@ func Detect(ctx *config.ProjectContext) (schema.Provider, error) {
 	}
 
 	if ctx.ProjectConfig.TerraformParseHCL {
+		if isTerragruntNestedDir(path, 5) {
+			return terraform.NewTerragruntHCLProvider(ctx, includePastResources), nil
+		}
+
 		h, providerErr := terraform.NewHCLProvider(
 			ctx,
-			terraform.NewPlanJSONProvider(ctx),
+			terraform.NewPlanJSONProvider(ctx, includePastResources),
 			hcl.OptionWithSpinner(ctx.RunContext.NewSpinner),
 			hcl.OptionWithWarningFunc(ctx.RunContext.NewWarningWriter()),
 		)
@@ -70,31 +73,31 @@ func Detect(ctx *config.ProjectContext) (schema.Provider, error) {
 	}
 
 	if isCloudFormationTemplate(path) {
-		return cloudformation.NewTemplateProvider(ctx), nil
+		return cloudformation.NewTemplateProvider(ctx, includePastResources), nil
 	}
 
 	if isTerraformPlanJSON(path) {
-		return terraform.NewPlanJSONProvider(ctx), nil
+		return terraform.NewPlanJSONProvider(ctx, includePastResources), nil
 	}
 
 	if isTerraformStateJSON(path) {
-		return terraform.NewStateJSONProvider(ctx), nil
+		return terraform.NewStateJSONProvider(ctx, includePastResources), nil
 	}
 
 	if isTerraformPlan(path) {
-		return terraform.NewPlanProvider(ctx), nil
+		return terraform.NewPlanProvider(ctx, includePastResources), nil
 	}
 
 	if isTerragruntDir(path) {
-		return terraform.NewTerragruntProvider(ctx), nil
+		return terraform.NewTerragruntProvider(ctx, includePastResources), nil
 	}
 
 	if isTerraformDir(path) {
-		return terraform.NewDirProvider(ctx), nil
+		return terraform.NewDirProvider(ctx, includePastResources), nil
 	}
 
 	if isTerragruntNestedDir(path, 5) {
-		return terraform.NewTerragruntProvider(ctx), nil
+		return terraform.NewTerragruntProvider(ctx, includePastResources), nil
 	}
 
 	return nil, fmt.Errorf("Could not detect path type for '%s'", path)
@@ -131,14 +134,6 @@ func validateProjectForHCL(ctx *config.ProjectContext, path string) error {
 		}
 	}
 
-	for _, k := range os.Environ() {
-		if strings.HasPrefix(k, "TF_VAR") {
-			return &ValidationError{
-				warn: "The parse HCL option does not support use of TF_VARS through environment variables, use --terraform-var-file or --terraform-var instead.",
-			}
-		}
-	}
-
 	return nil
 }
 
