@@ -42,14 +42,21 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getEC2TransitGatewayPeeringAttachmentRegistryItem(),
 	getEC2TransitGatewayVpcAttachmentRegistryItem(),
 	getECRRegistryItem(),
+	getECSClusterCapacityProvidersRegistryItem(),
+	getECSClusterRegistryItem(),
 	getECSServiceRegistryItem(),
 	getEFSFileSystemRegistryItem(),
 	getEIPRegistryItem(),
+	getEIPAssociationRegistryItem(),
+	getElasticBeanstalkEnvironmentRegistryItem(),
 	getElastiCacheClusterItem(),
 	getElastiCacheReplicationGroupItem(),
 	getElasticsearchDomainRegistryItem(),
 	getELBRegistryItem(),
 	getFSxWindowsFSRegistryItem(),
+	getGlueCatalogDatabaseRegistryItem(),
+	getGlueCrawlerRegistryItem(),
+	getGlueJobRegistryItem(),
 	getInstanceRegistryItem(),
 	getKinesisAnalyticsApplicationRegistryItem(),
 	getKinesisAnalyticsV2ApplicationRegistryItem(),
@@ -95,10 +102,15 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getStepFunctionRegistryItem(),
 	getDirectoryServiceDirectory(),
 	getTransferServerRegistryItem(),
+	getNetworkfirewallFirewallRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
 var FreeResources = []string{
+	// AWS Application Auto Scaling
+	"aws_appautoscaling_policy",
+	"aws_appautoscaling_scheduled_action",
+
 	// AWS Certificate Manager
 	"aws_acm_certificate_validation",
 
@@ -197,8 +209,11 @@ var FreeResources = []string{
 	"aws_ecr_lifecycle_policy",
 	"aws_ecr_repository_policy",
 
+	// AWS Elastic Beanstalk
+	"aws_elastic_beanstalk_application",
+
 	// AWS Elastic Container Service
-	"aws_ecs_capacity_provider",
+	"aws_ecs_account_setting_default",
 
 	// AWS Elastic File System
 	"aws_efs_access_point",
@@ -229,6 +244,21 @@ var FreeResources = []string{
 	"aws_elasticache_security_group",
 	"aws_elasticache_subnet_group",
 
+	// AWS Glue
+	"aws_glue_catalog_table",
+	"aws_glue_classifier",
+	"aws_glue_connection",
+	"aws_glue_data_catalog_encryption_settings",
+	"aws_glue_partition",
+	"aws_glue_partition_index",
+	"aws_glue_registry",
+	"aws_glue_resource_policy",
+	"aws_glue_schema",
+	"aws_glue_security_configuration",
+	"aws_glue_trigger",
+	"aws_glue_user_defined_function",
+	"aws_glue_workflow",
+
 	// AWS IAM aws_iam_* resources
 	"aws_iam_access_key",
 	"aws_iam_account_alias",
@@ -284,8 +314,14 @@ var FreeResources = []string{
 	"aws_neptune_parameter_group",
 	"aws_neptune_subnet_group",
 
+	// AWS Network Firewall
+	"aws_networkfirewall_rule_group",
+	"aws_networkfirewall_firewall_policy",
+	"aws_networkfirewall_logging_configuration",
+
 	// AWS Others
 	"aws_db_instance_role_association",
+	"aws_db_option_group",
 	"aws_db_parameter_group",
 	"aws_db_subnet_group",
 	"aws_dms_replication_subnet_group",
@@ -295,9 +331,7 @@ var FreeResources = []string{
 	"aws_dynamodb_table_item",
 	"aws_ebs_encryption_by_default",
 	"aws_ebs_default_kms_key",
-	"aws_ecs_cluster",
 	"aws_ecs_task_definition",
-	"aws_eip_association",
 	"aws_elasticsearch_domain_policy",
 	"aws_key_pair",
 	"aws_launch_configuration",
@@ -345,6 +379,10 @@ var FreeResources = []string{
 	// AWS Service Discovery Service
 	"aws_service_discovery_service",
 
+	// AWS SES
+	"aws_ses_domain_dkim",
+	"aws_ses_domain_identity",
+
 	// AWS SNS
 	"aws_sns_platform_application",
 	"aws_sns_sms_preferences",
