@@ -6,22 +6,22 @@ import "github.com/infracost/infracost/internal/schema"
 var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMActiveDirectoryDomainServiceRegistryItem(),
 	GetAzureRMActiveDirectoryDomainServiceReplicaSetRegistryItem(),
-	GetAzureRMApiManagementRegistryItem(),
+	getAPIManagementRegistryItem(),
 	GetAzureRMApplicationGatewayRegistryItem(),
-	GetAzureRMAppIsolatedServicePlanRegistryItem(),
+	getAppServiceEnvironmentRegistryItem(),
 	GetAzureRMAppIntegrationServiceEnvironmentRegistryItem(),
 	GetAzureRMAppFunctionRegistryItem(),
 	GetAzureRMAppNATGatewayRegistryItem(),
-	GetAzureRMAppServiceCertificateBindingRegistryItem(),
-	GetAzureRMAppServiceCertificateOrderRegistryItem(),
+	getAppServiceCertificateBindingRegistryItem(),
+	getAppServiceCertificateOrderRegistryItem(),
 	GetAzureRMAppServiceCustomHostnameBindingRegistryItem(),
 	GetAzureRMAppServicePlanRegistryItem(),
-	GetAzureRMApplicationInsightsWebRegistryItem(),
-	GetAzureRMApplicationInsightsRegistryItem(),
-	GetAzureRMAutomationAccountRegistryItem(),
-	GetAzureRMAutomationDscConfigurationRegistryItem(),
-	GetAzureRMAutomationDscNodeconfigurationRegistryItem(),
-	GetAzureRMAutomationJobScheduleRegistryItem(),
+	getApplicationInsightsWebTestRegistryItem(),
+	getApplicationInsightsRegistryItem(),
+	getAutomationAccountRegistryItem(),
+	getAutomationDSCConfigurationRegistryItem(),
+	getAutomationDSCNodeConfigurationRegistryItem(),
+	getAutomationJobScheduleRegistryItem(),
 	GetAzureRMBastionHostRegistryItem(),
 	GetAzureRMCDNEndpointRegistryItem(),
 	GetAzureRMContainerRegistryRegistryItem(),
